@@ -64,7 +64,7 @@ class ListImagesSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         list_parser = parser.add_parser(
             "list-images",
-            help="list images",
+            help="List images",
         )
 
         list_parser.add_argument(
@@ -160,7 +160,7 @@ class ListImagesSubCommand(SubCommand):
         )
         if not images:
             print("No matching images found.")
-            sys.exit(1)
+            return
 
         if self.format == "json":
             print(json.dumps([img.to_dict() for img in images], indent=2))
@@ -196,8 +196,8 @@ class SaveImagesSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         save_parser = parser.add_parser(
             "save-images",
-            help="save images as Docker Archive to local path, "
-            "power by https://github.com/containers/skopeo",
+            help="Save images as Docker Archive to local path, "
+            "powered by https://github.com/containers/skopeo",
         )
 
         save_parser.add_argument(
@@ -354,7 +354,7 @@ class SaveImagesSubCommand(SubCommand):
         )
         if not images:
             print("No matching images found.")
-            sys.exit(1)
+            return
 
         if self.source_namespace:
             # The original name of image doesn't include registry,
@@ -432,10 +432,8 @@ class SaveImagesSubCommand(SubCommand):
                 if self.source_username and self.source_password:
                     command.extend(
                         [
-                            "--src-username",
-                            self.source_username,
-                            "--src-password",
-                            self.source_password,
+                            "--src-creds",
+                            f"{self.source_username}:{self.source_password}",
                         ],
                     )
                 command.extend(
@@ -464,8 +462,8 @@ class SaveImagesSubCommand(SubCommand):
                 raise
 
             # Review
+            print()
             if failures:
-                print()
                 print(f"⚠️ Error downloading {len(failures)} images:")
                 for name, err in failures:
                     print(f"  - {name}:")
@@ -506,8 +504,8 @@ class CopyImagesSubCommand(SubCommand):
     def register(parser: _SubParsersAction):
         copy_parser = parser.add_parser(
             "copy-images",
-            help="copy images to other registry, "
-            "power by https://github.com/containers/skopeo",
+            help="Copy images to other registry, "
+            "powered by https://github.com/containers/skopeo",
         )
 
         copy_parser.add_argument(
@@ -688,7 +686,7 @@ class CopyImagesSubCommand(SubCommand):
         )
         if not images:
             print("No matching images found.")
-            sys.exit(1)
+            return
 
         if self.source_namespace:
             # The original name of image doesn't include registry,
@@ -754,19 +752,15 @@ class CopyImagesSubCommand(SubCommand):
                 if self.source_username and self.source_password:
                     command.extend(
                         [
-                            "--src-username",
-                            self.source_username,
-                            "--src-password",
-                            self.source_password,
+                            "--src-creds",
+                            f"{self.source_username}:{self.source_password}",
                         ],
                     )
                 if self.destination_username and self.destination_password:
                     command.extend(
                         [
-                            "--dest-username",
-                            self.destination_username,
-                            "--dest-password",
-                            self.destination_password,
+                            "--dest-creds",
+                            f"{self.destination_username}:{self.destination_password}",
                         ],
                     )
                 dest_img_name = img.name
@@ -803,8 +797,8 @@ class CopyImagesSubCommand(SubCommand):
                 raise
 
             # Review
+            print()
             if failures:
-                print()
                 print(f"⚠️ Error syncing {len(failures)} images:")
                 for name, err in failures:
                     print(f"  - {name}:")
@@ -862,14 +856,11 @@ def list_images(**kwargs) -> list[PlatformedImage]:
     platform = kwargs.pop("platform", None)
     repository = kwargs.pop("repository", None)
 
-    backend_runners: BackendRunners = list_backend_runners(**kwargs)
-    if not backend_runners:
-        return _EXTRA_IMAGES
-
     image_names_index: dict[str, int] = {}
     images: list[PlatformedImage] = []
 
-    for runner in backend_runners:
+    backend_runners: BackendRunners = list_backend_runners(**kwargs)
+    for runner in backend_runners or []:
         for b_version in runner.versions:
             for b_variant in b_version.variants:
                 for service in b_variant.services:
@@ -926,7 +917,7 @@ def _ensure_required_tools():
 
     """
     if not shutil.which("skopeo"):
-        msg = "Skopeo is not found. Please follow https://github.com/containers/skopeo/blob/v1.20.0/install.md to install."
+        msg = "Skopeo is not found. Please follow https://github.com/containers/skopeo/blob/v1.13.3/install.md to install."
         raise RuntimeError(msg)
 
 
